---
title: Attribute Lists
---

The theme may provide some pre-computed classes. The `attr_list` extension (with `extra`) allows to customize the attribute of the output html. Here is a example with the `reference` class.

```md
[Reference](https://python-markdown.github.io/extensions/attr_list/){: class="reference" }
```


[Reference](https://python-markdown.github.io/extensions/attr_list/){: class="reference" }
